@@ -154,13 +154,15 @@ class BaseMesh(HalfEdge):
             lines = [(vertices[u], vertices[v], 0) for u, v in edges]
             return cls.from_lines(lines)
 
-    def to_obj(self, filepath):
+    def to_obj(self, filepath, precision=None, **kwargs):
         """Write the mesh to an OBJ file.
 
         Parameters
         ----------
         filepath : str
             Full path of the file.
+        precision: str, optional
+            The precision of the geometric map that is used to connect the lines.
 
         Warning
         -------
@@ -169,22 +171,13 @@ class BaseMesh(HalfEdge):
 
         Examples
         --------
-        .. code-block:: python
-
-            pass
-
+        >>>
         """
-        key_index = self.key_index()
-        with open(filepath, 'w+') as f:
-            for key, attr in self.vertices(True):
-                f.write('v {0[x]:.3f} {0[y]:.3f} {0[z]:.3f}\n'.format(attr))
-            for fkey in self.faces():
-                vertices = self.face_vertices(fkey)
-                vertices = [key_index[key] + 1 for key in vertices]
-                f.write(' '.join(['f'] + [str(index) for index in vertices]) + '\n')
+        obj = OBJ(filepath, precision=precision)
+        obj.write(self, **kwargs)
 
     @classmethod
-    def from_ply(cls, filepath):
+    def from_ply(cls, filepath, precision=None):
         """Construct a mesh object from the data described in a PLY file.
 
         Parameters
@@ -235,13 +228,15 @@ class BaseMesh(HalfEdge):
         ply.write(self, **kwargs)
 
     @classmethod
-    def from_stl(cls, filepath):
+    def from_stl(cls, filepath, precision=None):
         """Construct a mesh object from the data described in a STL file.
 
         Parameters
         ----------
         filepath : str
             The path to the file.
+        precision: str, optional
+            The precision of the geometric map that is used to connect the lines.
 
         Returns
         -------
@@ -259,7 +254,7 @@ class BaseMesh(HalfEdge):
         --------
         >>>
         """
-        stl = STL(filepath)
+        stl = STL(filepath, precision)
         vertices = stl.parser.vertices
         faces = stl.parser.faces
         mesh = cls.from_vertices_and_faces(vertices, faces)
@@ -408,22 +403,26 @@ class BaseMesh(HalfEdge):
         >>>
         """
         mesh = cls()
+
         if sys.version_info[0] < 3:
             mapping = collections.Mapping
         else:
             mapping = collections.abc.Mapping
+
         if isinstance(vertices, mapping):
             for key, xyz in vertices.items():
                 mesh.add_vertex(key=key, attr_dict={i: j for i, j in zip(['x', 'y', 'z'], xyz)})
         else:
             for x, y, z in iter(vertices):
                 mesh.add_vertex(x=x, y=y, z=z)
+
         if isinstance(faces, mapping):
             for fkey, vertices in faces.items():
                 mesh.add_face(vertices, fkey)
         else:
             for face in iter(faces):
                 mesh.add_face(face)
+
         return mesh
 
     def to_vertices_and_faces(self):
@@ -1005,7 +1004,7 @@ class BaseMesh(HalfEdge):
         fkey : int
             The identifier of the face.
         axes : str, optional
-            The axes alon which to take the coordinates.
+            The axes along which to take the coordinates.
             Should be a combination of ``'x'``, ``'y'``, ``'z'``.
             Default is ``'xyz'``.
 
